@@ -33,3 +33,14 @@
 		stop("Please install ", pkg, " or use another file format", call. = FALSE);
 	}
 }
+
+# To support R < 3.2, provide trimws definition
+trimws <- function (x, which = c("both", "left", "right")) {
+	which <- match.arg(which)
+	mysub <- function(re, x) sub(re, "", x, perl = TRUE)
+	if (which == "left") 
+		return(mysub("^[ \t\r\n]+", x))
+	if (which == "right") 
+		return(mysub("[ \t\r\n]+$", x))
+	mysub("[ \t\r\n]+$", mysub("^[ \t\r\n]+", x))
+}
