@@ -1,13 +1,15 @@
 #' @method qread xml
 #' @export
 qread.xml <- function(file, type, ...) {
-	require(XML);
+	.check_package("XML");
+
 	XML::xmlParse(file, ...)
 }
 
 #' @method qwrite xml
 #' @export
 qwrite.xml <- function(x, file, type, ...) {
-	require(XML);
+	.check_package("XML");
+
 	XML::saveXML(x, file, ...)
 }
